import json
from dataclasses import dataclass
from typing import Any

import httpx
import typer
from pydantic import BaseModel

from revornix.session import Session


@dataclass(slots=True)
class AppConfig:
    base_url: str | None
    api_key: str | None


def _to_output_data(payload: Any) -> Any:
    if isinstance(payload, BaseModel):
        return payload.model_dump(mode="json", exclude_none=True)
    if isinstance(payload, dict):
        return {key: _to_output_data(value) for key, value in payload.items()}
    if isinstance(payload, (list, tuple)):
        return [_to_output_data(item) for item in payload]
    return payload


def dump_output(payload: Any) -> None:
    data = _to_output_data(payload)
    typer.echo(json.dumps(data, ensure_ascii=False, indent=2))


def handle_api_call(callback: Any) -> None:
    try:
        dump_output(callback())
    except httpx.HTTPStatusError as exc:
        response_text = exc.response.text.strip() if exc.response is not None else ""
        message = response_text or str(exc)
        typer.secho(message, fg=typer.colors.RED, err=True)
        raise typer.Exit(code=1) from exc
    except httpx.HTTPError as exc:
        typer.secho(str(exc), fg=typer.colors.RED, err=True)
        raise typer.Exit(code=1) from exc


def credentials_from_context(ctx: typer.Context) -> tuple[str, str]:
    config = ctx.obj
    if not config.base_url:
        typer.secho(
            "Missing Revornix base URL. Use --base-url or REVORNIX_BASE_URL.",
            fg=typer.colors.RED,
            err=True,
        )
        raise typer.Exit(code=2)
    if not config.api_key:
        typer.secho(
            "Missing Revornix API key. Use --api-key or REVORNIX_API_KEY.",
            fg=typer.colors.RED,
            err=True,
        )
        raise typer.Exit(code=2)
    return config.base_url, config.api_key


def session_from_context(ctx: typer.Context) -> Session:
    base_url, api_key = credentials_from_context(ctx)
    return Session(base_url=base_url, api_key=api_key)


def normalize_ids(values: list[int] | None) -> list[int]:
    return list(values or [])


def optional_ids(values: list[int] | None) -> list[int] | None:
    if values is None:
        return None
    return list(values)


def parse_bool(value: str) -> bool:
    normalized = value.strip().lower()
    if normalized in {"1", "true", "yes", "on"}:
        return True
    if normalized in {"0", "false", "no", "off"}:
        return False
    raise typer.BadParameter("Expected a boolean value: true or false.")


def parse_optional_bool(value: str | None) -> bool | None:
    if value is None:
        return None
    return parse_bool(value)



from typing import Annotated

import typer

import revornix.schema.section as SectionSchema
from revornix.cli.shared import (
    handle_api_call,
    normalize_ids,
    optional_ids,
    parse_bool,
    parse_optional_bool,
    session_from_context,
)


app = typer.Typer(help="Section operations.", no_args_is_help=True)


@app.command("list")
def list_sections(ctx: typer.Context) -> None:
    session = session_from_context(ctx)
    handle_api_call(session.get_mine_all_sections)


@app.command("create")
def create_section(
    ctx: typer.Context,
    title: Annotated[str, typer.Option(..., "--title", help="Section title.")],
    description: Annotated[
        str,
        typer.Option(..., "--description", help="Section description."),
    ],
    process_task_trigger_type: Annotated[
        int,
        typer.Option(
            ...,
            "--process-task-trigger-type",
            help="Revornix process task trigger type.",
        ),
    ],
    labels: Annotated[
        list[int] | None,
        typer.Option("--label", help="Label id. Repeat the option for multiple values."),
    ] = None,
    cover: Annotated[str | None, typer.Option("--cover")] = None,
    process_task_trigger_scheduler: Annotated[
        str | None,
        typer.Option("--process-task-trigger-scheduler"),
    ] = None,
    auto_publish: Annotated[bool, typer.Option("--auto-publish")] = False,
    auto_podcast: Annotated[bool, typer.Option("--auto-podcast")] = False,
    auto_illustration: Annotated[bool, typer.Option("--auto-illustration")] = False,
) -> None:
    session = session_from_context(ctx)
    payload = SectionSchema.SectionCreateRequest(
        title=title,
        description=description,
        cover=cover,
        labels=normalize_ids(labels),
        auto_publish=auto_publish,
        auto_podcast=auto_podcast,
        auto_illustration=auto_illustration,
        process_task_trigger_type=process_task_trigger_type,
        process_task_trigger_scheduler=process_task_trigger_scheduler,
    )
    handle_api_call(lambda: session.create_section(payload))


@app.command("detail")
def get_section_detail(
    ctx: typer.Context,
    section_id: Annotated[int, typer.Option(..., "--section-id", help="Section id.")],
) -> None:
    session = session_from_context(ctx)
    payload = SectionSchema.SectionDetailRequest(section_id=section_id)
    handle_api_call(lambda: session.get_section_detail(payload))


@app.command("documents")
def get_section_documents(
    ctx: typer.Context,
    section_id: Annotated[int, typer.Option(..., "--section-id", help="Section id.")],
    keyword: Annotated[str | None, typer.Option("--keyword")] = None,
    start: Annotated[int | None, typer.Option("--start")] = None,
    limit: Annotated[int, typer.Option("--limit")] = 10,
    desc: Annotated[str, typer.Option("--desc", help="Sort descending: true or false.")] = "true",
) -> None:
    session = session_from_context(ctx)
    payload = SectionSchema.SectionDocumentRequest(
        section_id=section_id,
        keyword=keyword,
        start=start,
        limit=limit,
        desc=parse_bool(desc),
    )
    handle_api_call(lambda: session.get_section_documents(payload))


@app.command("search-mine")
def search_mine_sections(
    ctx: typer.Context,
    labels: Annotated[
        list[int] | None,
        typer.Option("--label", help="Label id. Repeat the option for multiple values."),
    ] = None,
    keyword: Annotated[str | None, typer.Option("--keyword")] = None,
    start: Annotated[int | None, typer.Option("--start")] = None,
    limit: Annotated[int, typer.Option("--limit")] = 10,
    desc: Annotated[str, typer.Option("--desc", help="Sort descending: true or false.")] = "true",
) -> None:
    session = session_from_context(ctx)
    payload = SectionSchema.SearchMineSectionsRequest(
        keyword=keyword,
        start=start,
        limit=limit,
        label_ids=optional_ids(labels),
        desc=parse_bool(desc),
    )
    handle_api_call(lambda: session.search_mine_sections(payload))


@app.command("update")
def update_section(
    ctx: typer.Context,
    section_id: Annotated[int, typer.Option(..., "--section-id", help="Section id.")],
    labels: Annotated[
        list[int] | None,
        typer.Option("--label", help="Label id. Repeat the option for multiple values."),
    ] = None,
    title: Annotated[str | None, typer.Option("--title")] = None,
    description: Annotated[str | None, typer.Option("--description")] = None,
    cover: Annotated[str | None, typer.Option("--cover")] = None,
    auto_podcast: Annotated[
        str | None,
        typer.Option("--auto-podcast", help="Set auto podcast to true or false."),
    ] = None,
    auto_illustration: Annotated[
        str | None,
        typer.Option("--auto-illustration", help="Set auto illustration to true or false."),
    ] = None,
    process_task_trigger_type: Annotated[int | None, typer.Option("--process-task-trigger-type")] = None,
    process_task_trigger_scheduler: Annotated[
        str | None,
        typer.Option("--process-task-trigger-scheduler"),
    ] = None,
) -> None:
    session = session_from_context(ctx)
    payload = SectionSchema.SectionUpdateRequest(
        section_id=section_id,
        title=title,
        description=description,
        cover=cover,
        labels=optional_ids(labels),
        auto_podcast=parse_optional_bool(auto_podcast),
        auto_illustration=parse_optional_bool(auto_illustration),
        process_task_trigger_type=process_task_trigger_type,
        process_task_trigger_scheduler=process_task_trigger_scheduler,
    )
    handle_api_call(lambda: session.update_section(payload))


@app.command("delete")
def delete_section(
    ctx: typer.Context,
    section_id: Annotated[int, typer.Option(..., "--section-id", help="Section id.")],
) -> None:
    session = session_from_context(ctx)
    payload = SectionSchema.SectionDeleteRequest(section_id=section_id)
    handle_api_call(lambda: session.delete_section(payload))


@app.command("publish")
def publish_section(
    ctx: typer.Context,
    section_id: Annotated[int, typer.Option(..., "--section-id", help="Section id.")],
    status: Annotated[str, typer.Option(..., "--status", help="Publish status: true or false.")],
) -> None:
    session = session_from_context(ctx)
    payload = SectionSchema.SectionPublishRequest(section_id=section_id, status=parse_bool(status))
    handle_api_call(lambda: session.publish_section(payload))


@app.command("get-publish")
def get_section_publish(
    ctx: typer.Context,
    section_id: Annotated[int, typer.Option(..., "--section-id", help="Section id.")],
) -> None:
    session = session_from_context(ctx)
    payload = SectionSchema.SectionPublishGetRequest(section_id=section_id)
    handle_api_call(lambda: session.get_section_publish(payload))


@app.command("republish")
def republish_section(
    ctx: typer.Context,
    section_id: Annotated[int, typer.Option(..., "--section-id", help="Section id.")],
) -> None:
    session = session_from_context(ctx)
    payload = SectionSchema.SectionRePublishRequest(section_id=section_id)
    handle_api_call(lambda: session.republish_section(payload))



from datetime import datetime

from pydantic import BaseModel, Field

from revornix.schema.task import SectionPodcastTask, SectionProcessTask
from revornix.schema.user import UserPublicInfo


class LabelAddRequest(BaseModel):
    name: str


class LabelDeleteRequest(BaseModel):
    label_ids: list[int]


class SectionLabel(BaseModel):
    id: int
    name: str


Label = SectionLabel


class BaseSectionInfo(BaseModel):
    id: int
    title: str
    description: str | None = None
    authority: int | None = None
    publish_uuid: str | None = None


class AllMySectionsResponse(BaseModel):
    data: list[BaseSectionInfo]


class LabelListResponse(BaseModel):
    data: list[SectionLabel]


class CreateLabelResponse(BaseModel):
    id: int
    name: str


class SectionDocumentRequest(BaseModel):
    section_id: int
    start: int | None = None
    limit: int = 10
    desc: bool = True
    keyword: str | None = None


class SectionDetailRequest(BaseModel):
    section_id: int


class SectionDeleteRequest(BaseModel):
    section_id: int


class SearchMineSectionsRequest(BaseModel):
    keyword: str | None = None
    start: int | None = None
    limit: int = 10
    label_ids: list[int] | None = None
    desc: bool = True


class SectionPublishRequest(BaseModel):
    section_id: int
    status: bool


class SectionPublishGetRequest(BaseModel):
    section_id: int


class SectionPublishGetResponse(BaseModel):
    status: bool
    uuid: str | None = None
    create_time: datetime | None = None
    update_time: datetime | None = None


class SectionRePublishRequest(BaseModel):
    section_id: int


class SectionDocumentInfo(BaseModel):
    id: int
    title: str
    status: int
    category: int
    cover: str | None = None
    description: str | None = None
    from_plat: str | None = None
    labels: list[SectionLabel] | None = None
    users: list[UserPublicInfo] | None = None
    create_time: datetime
    update_time: datetime | None = None


class SectionDocumentIntegrationSummary(BaseModel):
    wait_to_count: int = 0
    supplementing_count: int = 0
    success_count: int = 0
    failed_count: int = 0


class SectionInfo(BaseModel):
    id: int
    title: str
    creator: UserPublicInfo
    description: str
    auto_podcast: bool
    auto_illustration: bool
    documents_count: int = 0
    subscribers_count: int = 0
    create_time: datetime
    update_time: datetime | None = None
    authority: int | None = None
    is_subscribed: bool | None = None
    md_file_name: str | None = None
    labels: list[SectionLabel] | None = None
    cover: str | None = None
    publish_uuid: str | None = None
    podcast_task: SectionPodcastTask | None = None
    process_task: SectionProcessTask | None = None
    document_integration: SectionDocumentIntegrationSummary | None = None
    process_task_trigger_type: int | None = None
    process_task_trigger_scheduler: str | None = None


class SectionCreateRequest(BaseModel):
    title: str
    description: str
    cover: str | None = None
    labels: list[int] = Field(default_factory=list)
    auto_publish: bool = False
    auto_podcast: bool = False
    auto_illustration: bool = False
    process_task_trigger_type: int
    process_task_trigger_scheduler: str | None = None


class SectionCreateResponse(BaseModel):
    id: int


class SectionUpdateRequest(BaseModel):
    section_id: int
    title: str | None = None
    description: str | None = None
    cover: str | None = None
    labels: list[int] | None = None
    auto_podcast: bool | None = None
    auto_illustration: bool | None = None
    process_task_trigger_type: int | None = None
    process_task_trigger_scheduler: str | None = None



class DocumentApi:
    create_document = "/tp/document/create"
    get_mine_all_document_labels = "/tp/document/label/list"
    create_document_label = "/tp/document/label/create"
    delete_document_label = "/tp/document/label/delete"
    get_document_detail = "/tp/document/detail"
    update_document = "/tp/document/update"
    delete_document = "/tp/document/delete"
    search_mine_documents = "/tp/document/search/mine"
    search_document_vector = "/tp/document/vector/search"



from pathlib import Path
from typing import Annotated

import typer

import revornix.schema.document as DocumentSchema
from revornix.cli.shared import (
    handle_api_call,
    normalize_ids,
    optional_ids,
    parse_bool,
    session_from_context,
)
from revornix.cli.workflows.documents import (
    upload_and_create_audio_document as upload_and_create_audio_document_workflow,
    upload_and_create_file_document as upload_and_create_file_document_workflow,
)


app = typer.Typer(help="Document operations.", no_args_is_help=True)


@app.command("create-file")
def create_file_document(
    ctx: typer.Context,
    file_name: Annotated[
        str,
        typer.Option(..., "--file-name", help="Uploaded file name in Revornix."),
    ],
    sections: Annotated[
        list[int] | None,
        typer.Option("--section", help="Section id. Repeat the option for multiple values."),
    ] = None,
    labels: Annotated[
        list[int] | None,
        typer.Option("--label", help="Label id. Repeat the option for multiple values."),
    ] = None,
    title: Annotated[str | None, typer.Option("--title")] = None,
    description: Annotated[str | None, typer.Option("--description")] = None,
    cover: Annotated[str | None, typer.Option("--cover")] = None,
    auto_summary: Annotated[bool, typer.Option("--auto-summary")] = False,
    auto_podcast: Annotated[bool, typer.Option("--auto-podcast")] = False,
    auto_tag: Annotated[bool, typer.Option("--auto-tag")] = False,
) -> None:
    session = session_from_context(ctx)
    payload = DocumentSchema.FileDocumentParameters(
        title=title,
        description=description,
        cover=cover,
        sections=normalize_ids(sections),
        labels=normalize_ids(labels),
        file_name=file_name,
        auto_summary=auto_summary,
        auto_podcast=auto_podcast,
        auto_tag=auto_tag,
    )
    handle_api_call(lambda: session.create_file_document(payload))


@app.command("upload-create-file")
def upload_and_create_file_document(
    ctx: typer.Context,
    local_file_path: Annotated[
        Path,
        typer.Option(
            ...,
            "--local-file-path",
            help="Local file to upload before creating the document.",
            exists=True,
            dir_okay=False,
            readable=True,
            resolve_path=True,
        ),
    ],
    remote_file_path: Annotated[
        str | None,
        typer.Option("--remote-file-path", help="Remote file path in Revornix. Defaults to local file name."),
    ] = None,
    file_name: Annotated[
        str | None,
        typer.Option("--file-name", help="Document file name in Revornix. Defaults to the remote file path."),
    ] = None,
    content_type: Annotated[
        str | None,
        typer.Option("--content-type", help="Uploaded file content type. Guessed from the local file if omitted."),
    ] = None,
    sections: Annotated[
        list[int] | None,
        typer.Option("--section", help="Section id. Repeat the option for multiple values."),
    ] = None,
    labels: Annotated[
        list[int] | None,
        typer.Option("--label", help="Label id. Repeat the option for multiple values."),
    ] = None,
    title: Annotated[str | None, typer.Option("--title")] = None,
    description: Annotated[str | None, typer.Option("--description")] = None,
    cover: Annotated[str | None, typer.Option("--cover")] = None,
    auto_summary: Annotated[bool, typer.Option("--auto-summary")] = False,
    auto_podcast: Annotated[bool, typer.Option("--auto-podcast")] = False,
    auto_tag: Annotated[bool, typer.Option("--auto-tag")] = False,
) -> None:
    session = session_from_context(ctx)
    handle_api_call(
        lambda: upload_and_create_file_document_workflow(
            session,
            local_file_path=local_file_path,
            remote_file_path=remote_file_path,
            content_type=content_type,
            file_name=file_name,
            title=title,
            description=description,
            cover=cover,
            sections=normalize_ids(sections),
            labels=normalize_ids(labels),
            auto_summary=auto_summary,
            auto_podcast=auto_podcast,
            auto_tag=auto_tag,
        )
    )


@app.command("create-website")
def create_website_document(
    ctx: typer.Context,
    url: Annotated[str, typer.Option(..., "--url", help="Website URL to import.")],
    sections: Annotated[
        list[int] | None,
        typer.Option("--section", help="Section id. Repeat the option for multiple values."),
    ] = None,
    labels: Annotated[
        list[int] | None,
        typer.Option("--label", help="Label id. Repeat the option for multiple values."),
    ] = None,
    title: Annotated[str | None, typer.Option("--title")] = None,
    description: Annotated[str | None, typer.Option("--description")] = None,
    cover: Annotated[str | None, typer.Option("--cover")] = None,
    auto_summary: Annotated[bool, typer.Option("--auto-summary")] = False,
    auto_podcast: Annotated[bool, typer.Option("--auto-podcast")] = False,
    auto_tag: Annotated[bool, typer.Option("--auto-tag")] = False,
) -> None:
    session = session_from_context(ctx)
    payload = DocumentSchema.WebsiteDocumentParameters(
        title=title,
        description=description,
        cover=cover,
        sections=normalize_ids(sections),
        labels=normalize_ids(labels),
        url=url,
        auto_summary=auto_summary,
        auto_podcast=auto_podcast,
        auto_tag=auto_tag,
    )
    handle_api_call(lambda: session.create_website_document(payload))


@app.command("create-quick-note")
def create_quick_note_document(
    ctx: typer.Context,
    content: Annotated[str, typer.Option(..., "--content", help="Quick note content.")],
    sections: Annotated[
        list[int] | None,
        typer.Option("--section", help="Section id. Repeat the option for multiple values."),
    ] = None,
    labels: Annotated[
        list[int] | None,
        typer.Option("--label", help="Label id. Repeat the option for multiple values."),
    ] = None,
    title: Annotated[str | None, typer.Option("--title")] = None,
    description: Annotated[str | None, typer.Option("--description")] = None,
    cover: Annotated[str | None, typer.Option("--cover")] = None,
    auto_summary: Annotated[bool, typer.Option("--auto-summary")] = False,
    auto_podcast: Annotated[bool, typer.Option("--auto-podcast")] = False,
    auto_tag: Annotated[bool, typer.Option("--auto-tag")] = False,
) -> None:
    session = session_from_context(ctx)
    payload = DocumentSchema.QuickNoteDocumentParameters(
        title=title,
        description=description,
        cover=cover,
        sections=normalize_ids(sections),
        labels=normalize_ids(labels),
        content=content,
        auto_summary=auto_summary,
        auto_podcast=auto_podcast,
        auto_tag=auto_tag,
    )
    handle_api_call(lambda: session.create_quick_note_document(payload))


@app.command("create-audio")
def create_audio_document(
    ctx: typer.Context,
    file_name: Annotated[
        str,
        typer.Option(..., "--file-name", help="Uploaded audio file name in Revornix."),
    ],
    sections: Annotated[
        list[int] | None,
        typer.Option("--section", help="Section id. Repeat the option for multiple values."),
    ] = None,
    labels: Annotated[
        list[int] | None,
        typer.Option("--label", help="Label id. Repeat the option for multiple values."),
    ] = None,
    title: Annotated[str | None, typer.Option("--title")] = None,
    description: Annotated[str | None, typer.Option("--description")] = None,
    cover: Annotated[str | None, typer.Option("--cover")] = None,
    auto_summary: Annotated[bool, typer.Option("--auto-summary")] = False,
    auto_podcast: Annotated[bool, typer.Option("--auto-podcast")] = False,
    auto_transcribe: Annotated[bool, typer.Option("--auto-transcribe")] = False,
    auto_tag: Annotated[bool, typer.Option("--auto-tag")] = False,
) -> None:
    session = session_from_context(ctx)
    payload = DocumentSchema.AudioDocumentParameters(
        title=title,
        description=description,
        cover=cover,
        sections=normalize_ids(sections),
        labels=normalize_ids(labels),
        file_name=file_name,
        auto_summary=auto_summary,
        auto_podcast=auto_podcast,
        auto_transcribe=auto_transcribe,
        auto_tag=auto_tag,
    )
    handle_api_call(lambda: session.create_audio_document(payload))


@app.command("upload-create-audio")
def upload_and_create_audio_document(
    ctx: typer.Context,
    local_file_path: Annotated[
        Path,
        typer.Option(
            ...,
            "--local-file-path",
            help="Local audio file to upload before creating the document.",
            exists=True,
            dir_okay=False,
            readable=True,
            resolve_path=True,
        ),
    ],
    remote_file_path: Annotated[
        str | None,
        typer.Option("--remote-file-path", help="Remote file path in Revornix. Defaults to local file name."),
    ] = None,
    file_name: Annotated[
        str | None,
        typer.Option("--file-name", help="Document file name in Revornix. Defaults to the remote file path."),
    ] = None,
    content_type: Annotated[
        str | None,
        typer.Option("--content-type", help="Uploaded file content type. Guessed from the local file if omitted."),
    ] = None,
    sections: Annotated[
        list[int] | None,
        typer.Option("--section", help="Section id. Repeat the option for multiple values."),
    ] = None,
    labels: Annotated[
        list[int] | None,
        typer.Option("--label", help="Label id. Repeat the option for multiple values."),
    ] = None,
    title: Annotated[str | None, typer.Option("--title")] = None,
    description: Annotated[str | None, typer.Option("--description")] = None,
    cover: Annotated[str | None, typer.Option("--cover")] = None,
    auto_summary: Annotated[bool, typer.Option("--auto-summary")] = False,
    auto_podcast: Annotated[bool, typer.Option("--auto-podcast")] = False,
    auto_transcribe: Annotated[bool, typer.Option("--auto-transcribe")] = False,
    auto_tag: Annotated[bool, typer.Option("--auto-tag")] = False,
) -> None:
    session = session_from_context(ctx)
    handle_api_call(
        lambda: upload_and_create_audio_document_workflow(
            session,
            local_file_path=local_file_path,
            remote_file_path=remote_file_path,
            content_type=content_type,
            file_name=file_name,
            title=title,
            description=description,
            cover=cover,
            sections=normalize_ids(sections),
            labels=normalize_ids(labels),
            auto_summary=auto_summary,
            auto_podcast=auto_podcast,
            auto_transcribe=auto_transcribe,
            auto_tag=auto_tag,
        )
    )


@app.command("detail")
def get_document_detail(
    ctx: typer.Context,
    document_id: Annotated[int, typer.Option(..., "--document-id", help="Document id.")],
) -> None:
    session = session_from_context(ctx)
    payload = DocumentSchema.DocumentDetailRequest(document_id=document_id)
    handle_api_call(lambda: session.get_document_detail(payload))


@app.command("update")
def update_document(
    ctx: typer.Context,
    document_id: Annotated[int, typer.Option(..., "--document-id", help="Document id.")],
    labels: Annotated[
        list[int] | None,
        typer.Option("--label", help="Label id. Repeat the option for multiple values."),
    ] = None,
    sections: Annotated[
        list[int] | None,
        typer.Option("--section", help="Section id. Repeat the option for multiple values."),
    ] = None,
    title: Annotated[str | None, typer.Option("--title")] = None,
    description: Annotated[str | None, typer.Option("--description")] = None,
    cover: Annotated[str | None, typer.Option("--cover")] = None,
) -> None:
    session = session_from_context(ctx)
    payload = DocumentSchema.DocumentUpdateRequest(
        document_id=document_id,
        title=title,
        description=description,
        cover=cover,
        labels=optional_ids(labels),
        sections=optional_ids(sections),
    )
    handle_api_call(lambda: session.update_document(payload))


@app.command("delete")
def delete_document(
    ctx: typer.Context,
    document_ids: Annotated[
        list[int],
        typer.Option("--document-id", help="Document id. Repeat the option for multiple values."),
    ],
) -> None:
    session = session_from_context(ctx)
    payload = DocumentSchema.DocumentDeleteRequest(document_ids=list(document_ids))
    handle_api_call(lambda: session.delete_document(payload))


@app.command("search-mine")
def search_mine_documents(
    ctx: typer.Context,
    labels: Annotated[
        list[int] | None,
        typer.Option("--label", help="Label id. Repeat the option for multiple values."),
    ] = None,
    keyword: Annotated[str | None, typer.Option("--keyword")] = None,
    start: Annotated[int | None, typer.Option("--start")] = None,
    limit: Annotated[int, typer.Option("--limit")] = 10,
    desc: Annotated[str, typer.Option("--desc", help="Sort descending: true or false.")] = "true",
) -> None:
    session = session_from_context(ctx)
    payload = DocumentSchema.SearchAllMyDocumentsRequest(
        keyword=keyword,
        start=start,
        limit=limit,
        label_ids=optional_ids(labels),
        desc=parse_bool(desc),
    )
    handle_api_call(lambda: session.search_mine_documents(payload))


@app.command("search-vector")
def search_document_vector(
    ctx: typer.Context,
    query: Annotated[str, typer.Option(..., "--query", help="Semantic query text.")],
) -> None:
    session = session_from_context(ctx)
    payload = DocumentSchema.VectorSearchRequest(query=query)
    handle_api_call(lambda: session.search_document_vector(payload))



from revornix.cli.workflows.documents import (
    guess_content_type,
    normalize_remote_file_path,
    upload_and_create_audio_document,
    upload_and_create_file_document,
)

__all__ = [
    "guess_content_type",
    "normalize_remote_file_path",
    "upload_and_create_audio_document",
    "upload_and_create_file_document",
]



import mimetypes
from pathlib import Path
from typing import Any

import revornix.schema.document as DocumentSchema
from revornix.session import Session


def guess_content_type(local_file_path: Path, explicit_content_type: str | None) -> str:
    if explicit_content_type:
        return explicit_content_type
    guessed, _ = mimetypes.guess_type(local_file_path.name)
    return guessed or "application/octet-stream"


def normalize_remote_file_path(local_file_path: Path, remote_file_path: str | None) -> str:
    return remote_file_path or local_file_path.name


def upload_and_create_file_document(
    session: Session,
    *,
    local_file_path: Path,
    remote_file_path: str | None,
    content_type: str | None,
    file_name: str | None,
    title: str | None,
    description: str | None,
    cover: str | None,
    sections: list[int],
    labels: list[int],
    auto_summary: bool,
    auto_podcast: bool,
    auto_tag: bool,
) -> dict[str, Any]:
    normalized_remote_file_path = normalize_remote_file_path(local_file_path, remote_file_path)
    normalized_content_type = guess_content_type(local_file_path, content_type)
    upload_result = session.upload_file(
        local_file_path=str(local_file_path),
        remote_file_path=normalized_remote_file_path,
        content_type=normalized_content_type,
    )
    document_result = session.create_file_document(
        DocumentSchema.FileDocumentParameters(
            title=title,
            description=description,
            cover=cover,
            sections=sections,
            labels=labels,
            file_name=file_name or normalized_remote_file_path,
            auto_summary=auto_summary,
            auto_podcast=auto_podcast,
            auto_tag=auto_tag,
        )
    )
    return {"upload": upload_result, "document": document_result}


def upload_and_create_audio_document(
    session: Session,
    *,
    local_file_path: Path,
    remote_file_path: str | None,
    content_type: str | None,
    file_name: str | None,
    title: str | None,
    description: str | None,
    cover: str | None,
    sections: list[int],
    labels: list[int],
    auto_summary: bool,
    auto_podcast: bool,
    auto_transcribe: bool,
    auto_tag: bool,
) -> dict[str, Any]:
    normalized_remote_file_path = normalize_remote_file_path(local_file_path, remote_file_path)
    normalized_content_type = guess_content_type(local_file_path, content_type)
    upload_result = session.upload_file(
        local_file_path=str(local_file_path),
        remote_file_path=normalized_remote_file_path,
        content_type=normalized_content_type,
    )
    document_result = session.create_audio_document(
        DocumentSchema.AudioDocumentParameters(
            title=title,
            description=description,
            cover=cover,
            sections=sections,
            labels=labels,
            file_name=file_name or normalized_remote_file_path,
            auto_summary=auto_summary,
            auto_podcast=auto_podcast,
            auto_transcribe=auto_transcribe,
            auto_tag=auto_tag,
        )
    )
    return {"upload": upload_result, "document": document_result}



from revornix.schema import document as DocumentSchema
from revornix.schema import section as SectionSchema
from revornix.schema import common as CommonSchema
from revornix.schema import pagination as PaginationSchema
from revornix.schema import task as TaskSchema
from revornix.schema import user as UserSchema



from datetime import datetime

from pydantic import BaseModel, Field

from revornix.schema.task import (
    DocumentConvertTask,
    DocumentEmbeddingTask,
    DocumentGraphTask,
    DocumentPodcastTask,
    DocumentProcessTask,
    DocumentSummarizeTask,
    DocumentTranscribeTask,
)
from revornix.schema.user import UserPublicInfo


class BaseSectionInfo(BaseModel):
    id: int
    title: str
    description: str | None = None
    publish_uuid: str | None = None


class DocumentLabel(BaseModel):
    id: int
    name: str


Label = DocumentLabel


class LabelListResponse(BaseModel):
    data: list[DocumentLabel]


class CreateLabelResponse(BaseModel):
    id: int
    name: str


class LabelAddRequest(BaseModel):
    name: str


class LabelDeleteRequest(BaseModel):
    label_ids: list[int]


class DocumentCreateResponse(BaseModel):
    document_id: int


class BaseDocumentParameters(BaseModel):
    title: str | None = None
    description: str | None = None
    cover: str | None = None
    sections: list[int] = Field(default_factory=list)
    labels: list[int] = Field(default_factory=list)
    auto_summary: bool = False
    auto_podcast: bool = False
    auto_tag: bool = False


class FileDocumentParameters(BaseDocumentParameters):
    file_name: str | None = None


class WebsiteDocumentParameters(BaseDocumentParameters):
    url: str | None = None


class QuickNoteDocumentParameters(BaseDocumentParameters):
    content: str | None = None


class AudioDocumentParameters(BaseDocumentParameters):
    file_name: str | None = None
    auto_transcribe: bool = False


class DocumentUpdateRequest(BaseModel):
    document_id: int
    title: str | None = None
    description: str | None = None
    cover: str | None = None
    labels: list[int] | None = None
    sections: list[int] | None = None


class SearchAllMyDocumentsRequest(BaseModel):
    keyword: str | None = None
    start: int | None = None
    limit: int = 10
    label_ids: list[int] | None = None
    desc: bool = True


class DocumentDeleteRequest(BaseModel):
    document_ids: list[int]


class DocumentDetailRequest(BaseModel):
    document_id: int


class VectorSearchRequest(BaseModel):
    query: str


class WebsiteDocumentInfo(BaseModel):
    url: str


class FileDocumentInfo(BaseModel):
    file_name: str


class QuickNoteDocumentInfo(BaseModel):
    content: str


class AudioDocumentInfo(BaseModel):
    audio_file_name: str


class DocumentInfo(BaseModel):
    id: int
    creator_id: int
    category: int
    title: str
    from_plat: str
    create_time: datetime
    update_time: datetime | None = None
    cover: str | None = None
    description: str | None = None
    labels: list[DocumentLabel] = Field(default_factory=list)
    sections: list[BaseSectionInfo] = Field(default_factory=list)
    users: list[UserPublicInfo] = Field(default_factory=list)
    convert_task: DocumentConvertTask | None = None
    embedding_task: DocumentEmbeddingTask | None = None
    graph_task: DocumentGraphTask | None = None
    podcast_task: DocumentPodcastTask | None = None
    summarize_task: DocumentSummarizeTask | None = None
    transcribe_task: DocumentTranscribeTask | None = None
    process_task: DocumentProcessTask | None = None


class DocumentDetailResponse(BaseModel):
    id: int
    category: int
    title: str
    from_plat: str
    description: str | None = None
    cover: str | None = None
    create_time: datetime
    update_time: datetime | None = None
    labels: list[DocumentLabel] = Field(default_factory=list)
    creator: UserPublicInfo
    sections: list[BaseSectionInfo] = Field(default_factory=list)
    users: list[UserPublicInfo] = Field(default_factory=list)
    is_star: bool | None = None
    is_read: bool | None = None
    website_info: WebsiteDocumentInfo | None = None
    file_info: FileDocumentInfo | None = None
    quick_note_info: QuickNoteDocumentInfo | None = None
    audio_info: AudioDocumentInfo | None = None
    convert_task: DocumentConvertTask | None = None
    embedding_task: DocumentEmbeddingTask | None = None
    graph_task: DocumentGraphTask | None = None
    podcast_task: DocumentPodcastTask | None = None
    summarize_task: DocumentSummarizeTask | None = None
    transcribe_task: DocumentTranscribeTask | None = None
    process_task: DocumentProcessTask | None = None


class VectorSearchResponse(BaseModel):
    documents: list[DocumentInfo] = Field(default_factory=list)



from pydantic import BaseModel
from pydantic.config import ConfigDict

class BaseResponseModel(BaseModel):
    model_config = ConfigDict(ser_json_exclude_none=True)
    
class SuccessResponse(BaseResponseModel):
    success: bool = True
    message: str | dict = "Success"
    code: int | None = 200
    
class ErrorResponse(BaseResponseModel):
    success: bool = False
    message: str = "Error"
    code: int | None = 400
    
class NormalResponse(BaseResponseModel):
    success: bool = True
    message: str = "Success"
    code: int | None = None


from pathlib import Path
from typing import Annotated

import typer

from revornix.cli.shared import handle_api_call, session_from_context


app = typer.Typer(help="File operations.", no_args_is_help=True)


@app.command("upload")
def upload_file(
    ctx: typer.Context,
    local_file_path: Annotated[
        Path,
        typer.Option(
            ...,
            "--local-file-path",
            help="Local file to upload.",
            exists=True,
            dir_okay=False,
            readable=True,
            resolve_path=True,
        ),
    ],
    remote_file_path: Annotated[
        str,
        typer.Option(..., "--remote-file-path", help="Remote file path in Revornix."),
    ],
    content_type: Annotated[
        str,
        typer.Option("--content-type", help="Uploaded file content type."),
    ] = "application/octet-stream",
) -> None:
    session = session_from_context(ctx)
    handle_api_call(
        lambda: session.upload_file(
            local_file_path=str(local_file_path),
            remote_file_path=remote_file_path,
            content_type=content_type,
        )
    )



from typing import Generic, TypeVar

from pydantic import BaseModel


T = TypeVar("T")


class InfiniteScrollPagination(BaseModel, Generic[T]):
    total: int
    start: int | None = None
    limit: int
    has_more: bool
    elements: list[T]
    next_start: int | None = None


InifiniteScrollPagnition = InfiniteScrollPagination



from datetime import datetime

from pydantic import BaseModel


class SectionUserPublicInfo(BaseModel):
    id: int
    avatar: str
    nickname: str
    slogan: str | None = None
    authority: int | None = None
    role: int | None = None
    create_time: datetime
    update_time: datetime | None = None


class UserPublicInfo(BaseModel):
    id: int
    role: int
    avatar: str
    nickname: str
    slogan: str | None = None
    is_followed: bool | None = None
    fans: int | None = None
    follows: int | None = None



from pydantic import BaseModel


class DocumentTranscribeTask(BaseModel):
    status: int
    transcribed_text: str | None = None


class DocumentConvertTask(BaseModel):
    status: int
    md_file_name: str | None = None


class DocumentSummarizeTask(BaseModel):
    status: int
    summary: str | None = None


class DocumentEmbeddingTask(BaseModel):
    status: int


class DocumentGraphTask(BaseModel):
    status: int


class DocumentProcessTask(BaseModel):
    status: int


class DocumentPodcastTask(BaseModel):
    status: int
    podcast_file_name: str | None = None


class SectionPodcastTask(BaseModel):
    status: int
    podcast_file_name: str | None = None


class SectionProcessTask(BaseModel):
    status: int



from typing import Annotated

import typer

import revornix.schema.document as DocumentSchema
import revornix.schema.section as SectionSchema
from revornix.cli.shared import handle_api_call, session_from_context


app = typer.Typer(help="Label operations.", no_args_is_help=True)


def _list_document_labels(ctx: typer.Context) -> None:
    session = session_from_context(ctx)
    handle_api_call(session.get_mine_all_document_labels)


def _create_document_label(
    ctx: typer.Context,
    name: Annotated[str, typer.Option(..., "--name", help="Document label name.")],
) -> None:
    session = session_from_context(ctx)
    payload = DocumentSchema.LabelAddRequest(name=name)
    handle_api_call(lambda: session.create_document_label(payload))


def _create_section_label(
    ctx: typer.Context,
    name: Annotated[str, typer.Option(..., "--name", help="Section label name.")],
) -> None:
    session = session_from_context(ctx)
    payload = SectionSchema.LabelAddRequest(name=name)
    handle_api_call(lambda: session.create_section_label(payload))


def _list_section_labels(ctx: typer.Context) -> None:
    session = session_from_context(ctx)
    handle_api_call(session.get_mine_all_section_labels)


def _delete_document_labels(
    ctx: typer.Context,
    label_ids: Annotated[
        list[int],
        typer.Option("--label-id", help="Document label id. Repeat the option for multiple values."),
    ],
) -> None:
    session = session_from_context(ctx)
    payload = DocumentSchema.LabelDeleteRequest(label_ids=list(label_ids))
    handle_api_call(lambda: session.delete_document_label(payload))


def _delete_section_labels(
    ctx: typer.Context,
    label_ids: Annotated[
        list[int],
        typer.Option("--label-id", help="Section label id. Repeat the option for multiple values."),
    ],
) -> None:
    session = session_from_context(ctx)
    payload = SectionSchema.LabelDeleteRequest(label_ids=list(label_ids))
    handle_api_call(lambda: session.delete_section_label(payload))


@app.command("list-document-labels")
def list_document_labels(ctx: typer.Context) -> None:
    _list_document_labels(ctx)


@app.command("create-document-label")
def create_document_label(
    ctx: typer.Context,
    name: Annotated[str, typer.Option(..., "--name", help="Document label name.")],
) -> None:
    _create_document_label(ctx, name)


@app.command("create-section-label")
def create_section_label(
    ctx: typer.Context,
    name: Annotated[str, typer.Option(..., "--name", help="Section label name.")],
) -> None:
    _create_section_label(ctx, name)


@app.command("list-section-labels")
def list_section_labels(ctx: typer.Context) -> None:
    _list_section_labels(ctx)


@app.command("delete-document-labels")
def delete_document_labels(
    ctx: typer.Context,
    label_ids: Annotated[
        list[int],
        typer.Option("--label-id", help="Document label id. Repeat the option for multiple values."),
    ],
) -> None:
    _delete_document_labels(ctx, label_ids)


@app.command("delete-section-labels")
def delete_section_labels(
    ctx: typer.Context,
    label_ids: Annotated[
        list[int],
        typer.Option("--label-id", help="Section label id. Repeat the option for multiple values."),
    ],
) -> None:
    _delete_section_labels(ctx, label_ids)


@app.command("list-document", hidden=True)
def list_document_labels_legacy(ctx: typer.Context) -> None:
    _list_document_labels(ctx)


@app.command("create-document", hidden=True)
def create_document_label_legacy(
    ctx: typer.Context,
    name: Annotated[str, typer.Option(..., "--name", help="Document label name.")],
) -> None:
    _create_document_label(ctx, name)


@app.command("create-section", hidden=True)
def create_section_label_legacy(
    ctx: typer.Context,
    name: Annotated[str, typer.Option(..., "--name", help="Section label name.")],
) -> None:
    _create_section_label(ctx, name)


@app.command("list-section", hidden=True)
def list_section_labels_legacy(ctx: typer.Context) -> None:
    _list_section_labels(ctx)


@app.command("delete-document", hidden=True)
def delete_document_labels_legacy(
    ctx: typer.Context,
    label_ids: Annotated[
        list[int],
        typer.Option("--label-id", help="Document label id. Repeat the option for multiple values."),
    ],
) -> None:
    _delete_document_labels(ctx, label_ids)


@app.command("delete-section", hidden=True)
def delete_section_labels_legacy(
    ctx: typer.Context,
    label_ids: Annotated[
        list[int],
        typer.Option("--label-id", help="Section label id. Repeat the option for multiple values."),
    ],
) -> None:
    _delete_section_labels(ctx, label_ids)



class SectionApi:
    get_mine_all_section = "/tp/section/mine/all"
    create_section_label = "/tp/section/label/create"
    get_mine_all_section_labels = "/tp/section/label/list"
    delete_section_label = "/tp/section/label/delete"
    create_section = "/tp/section/create"
    update_section = "/tp/section/update"
    delete_section = "/tp/section/delete"
    get_section_detail = "/tp/section/detail"
    get_section_documents = "/tp/section/documents"
    search_mine_sections = "/tp/section/mine/search"
    publish_section = "/tp/section/publish"
    get_section_publish = "/tp/section/publish/get"
    republish_section = "/tp/section/republish"



from typing import Annotated

import typer

from revornix.cli.documents import app as documents_app
from revornix.cli.files import app as files_app
from revornix.cli.labels import app as labels_app
from revornix.cli.sections import app as sections_app
from revornix.cli.shared import AppConfig


app = typer.Typer(
    help="Command line interface for the Revornix API.",
    no_args_is_help=True,
)

app.add_typer(files_app, name="files")
app.add_typer(documents_app, name="documents")
app.add_typer(labels_app, name="labels")
app.add_typer(sections_app, name="sections")


@app.callback()
def main_callback(
    ctx: typer.Context,
    base_url: Annotated[
        str | None,
        typer.Option(
            "--base-url",
            help="Revornix API base URL.",
            envvar="REVORNIX_BASE_URL",
        ),
    ] = None,
    api_key: Annotated[
        str | None,
        typer.Option(
            "--api-key",
            help="Revornix API key.",
            envvar="REVORNIX_API_KEY",
        ),
    ] = None,
) -> None:
    ctx.obj = AppConfig(base_url=base_url, api_key=api_key)


def main() -> None:
    app()



from pathlib import Path
from typing import TypeVar

import httpx
from pydantic import BaseModel

import revornix.schema.common as CommonSchema
import revornix.schema.document as DocumentSchema
import revornix.schema.pagination as PaginationSchema
import revornix.schema.section as SectionSchema
from revornix.endpoints.document import DocumentApi
from revornix.endpoints.file import FileApi
from revornix.endpoints.section import SectionApi


ResponseModelT = TypeVar("ResponseModelT", bound=BaseModel)


class Session:
    api_key: str
    base_url: str
    from_plat: str = "revornix python package"
    httpx_client: httpx.Client

    def __init__(self, base_url: str, api_key: str):
        self.base_url = base_url
        self.api_key = api_key
        self.httpx_client = httpx.Client(
            base_url=self.base_url,
            headers={"Api-Key": self.api_key},
            timeout=15.0,
        )

    def _post_json(
        self,
        endpoint: str,
        response_model: type[ResponseModelT],
        payload: BaseModel | dict | None = None,
    ) -> ResponseModelT:
        if payload is None:
            response = self.httpx_client.post(endpoint)
        else:
            json_payload = payload.model_dump(exclude_none=True) if isinstance(payload, BaseModel) else payload
            response = self.httpx_client.post(endpoint, json=json_payload)
        response.raise_for_status()
        return response_model.model_validate(response.json())

    def _create_document(
        self,
        data: BaseModel,
        category: int,
    ) -> DocumentSchema.DocumentCreateResponse:
        payload = data.model_dump(exclude_none=True)
        payload["category"] = category
        payload["from_plat"] = self.from_plat
        return self._post_json(
            DocumentApi.create_document,
            DocumentSchema.DocumentCreateResponse,
            payload,
        )

    def upload_file(
        self,
        local_file_path: str,
        remote_file_path: str,
        content_type: str | None = "application/octet-stream",
    ) -> CommonSchema.NormalResponse:
        with open(local_file_path, "rb") as file_obj:
            files = {
                "file": (Path(local_file_path).name, file_obj, content_type),
            }
            data = {
                "file_path": remote_file_path,
                "content_type": content_type,
            }
            response = self.httpx_client.post(FileApi.upload_file, files=files, data=data)
            response.raise_for_status()
        return CommonSchema.NormalResponse.model_validate(response.json())

    def create_file_document(
        self,
        data: DocumentSchema.FileDocumentParameters,
    ) -> DocumentSchema.DocumentCreateResponse:
        return self._create_document(data, category=0)

    def create_website_document(
        self,
        data: DocumentSchema.WebsiteDocumentParameters,
    ) -> DocumentSchema.DocumentCreateResponse:
        return self._create_document(data, category=1)

    def create_quick_note_document(
        self,
        data: DocumentSchema.QuickNoteDocumentParameters,
    ) -> DocumentSchema.DocumentCreateResponse:
        return self._create_document(data, category=2)

    def create_audio_document(
        self,
        data: DocumentSchema.AudioDocumentParameters,
    ) -> DocumentSchema.DocumentCreateResponse:
        return self._create_document(data, category=3)

    def get_mine_all_document_labels(self) -> DocumentSchema.LabelListResponse:
        return self._post_json(
            DocumentApi.get_mine_all_document_labels,
            DocumentSchema.LabelListResponse,
        )

    def create_document_label(
        self,
        data: DocumentSchema.LabelAddRequest,
    ) -> DocumentSchema.CreateLabelResponse:
        return self._post_json(
            DocumentApi.create_document_label,
            DocumentSchema.CreateLabelResponse,
            data,
        )

    def delete_document_label(
        self,
        data: DocumentSchema.LabelDeleteRequest,
    ) -> CommonSchema.NormalResponse:
        return self._post_json(
            DocumentApi.delete_document_label,
            CommonSchema.NormalResponse,
            data,
        )

    def get_document_detail(
        self,
        data: DocumentSchema.DocumentDetailRequest,
    ) -> DocumentSchema.DocumentDetailResponse:
        return self._post_json(
            DocumentApi.get_document_detail,
            DocumentSchema.DocumentDetailResponse,
            data,
        )

    def update_document(
        self,
        data: DocumentSchema.DocumentUpdateRequest,
    ) -> CommonSchema.NormalResponse:
        return self._post_json(
            DocumentApi.update_document,
            CommonSchema.NormalResponse,
            data,
        )

    def delete_document(
        self,
        data: DocumentSchema.DocumentDeleteRequest,
    ) -> CommonSchema.NormalResponse:
        return self._post_json(
            DocumentApi.delete_document,
            CommonSchema.NormalResponse,
            data,
        )

    def search_mine_documents(
        self,
        data: DocumentSchema.SearchAllMyDocumentsRequest,
    ) -> PaginationSchema.InfiniteScrollPagination[DocumentSchema.DocumentInfo]:
        response_model = PaginationSchema.InfiniteScrollPagination[DocumentSchema.DocumentInfo]
        return self._post_json(
            DocumentApi.search_mine_documents,
            response_model,
            data,
        )

    def search_document_vector(
        self,
        data: DocumentSchema.VectorSearchRequest,
    ) -> DocumentSchema.VectorSearchResponse:
        return self._post_json(
            DocumentApi.search_document_vector,
            DocumentSchema.VectorSearchResponse,
            data,
        )

    def create_section_label(
        self,
        data: SectionSchema.LabelAddRequest,
    ) -> SectionSchema.CreateLabelResponse:
        return self._post_json(
            SectionApi.create_section_label,
            SectionSchema.CreateLabelResponse,
            data,
        )

    def get_mine_all_section_labels(self) -> SectionSchema.LabelListResponse:
        return self._post_json(
            SectionApi.get_mine_all_section_labels,
            SectionSchema.LabelListResponse,
        )

    def delete_section_label(
        self,
        data: SectionSchema.LabelDeleteRequest,
    ) -> CommonSchema.NormalResponse:
        return self._post_json(
            SectionApi.delete_section_label,
            CommonSchema.NormalResponse,
            data,
        )

    def create_section(
        self,
        data: SectionSchema.SectionCreateRequest,
    ) -> SectionSchema.SectionCreateResponse:
        return self._post_json(
            SectionApi.create_section,
            SectionSchema.SectionCreateResponse,
            data,
        )

    def update_section(
        self,
        data: SectionSchema.SectionUpdateRequest,
    ) -> CommonSchema.NormalResponse:
        return self._post_json(
            SectionApi.update_section,
            CommonSchema.NormalResponse,
            data,
        )

    def delete_section(
        self,
        data: SectionSchema.SectionDeleteRequest,
    ) -> CommonSchema.NormalResponse:
        return self._post_json(
            SectionApi.delete_section,
            CommonSchema.NormalResponse,
            data,
        )

    def get_section_detail(
        self,
        data: SectionSchema.SectionDetailRequest,
    ) -> SectionSchema.SectionInfo:
        return self._post_json(
            SectionApi.get_section_detail,
            SectionSchema.SectionInfo,
            data,
        )

    def get_section_documents(
        self,
        data: SectionSchema.SectionDocumentRequest,
    ) -> PaginationSchema.InfiniteScrollPagination[SectionSchema.SectionDocumentInfo]:
        response_model = PaginationSchema.InfiniteScrollPagination[SectionSchema.SectionDocumentInfo]
        return self._post_json(
            SectionApi.get_section_documents,
            response_model,
            data,
        )

    def get_mine_all_sections(self) -> SectionSchema.AllMySectionsResponse:
        return self._post_json(
            SectionApi.get_mine_all_section,
            SectionSchema.AllMySectionsResponse,
        )

    def search_mine_sections(
        self,
        data: SectionSchema.SearchMineSectionsRequest,
    ) -> PaginationSchema.InfiniteScrollPagination[SectionSchema.SectionInfo]:
        response_model = PaginationSchema.InfiniteScrollPagination[SectionSchema.SectionInfo]
        return self._post_json(
            SectionApi.search_mine_sections,
            response_model,
            data,
        )

    def publish_section(
        self,
        data: SectionSchema.SectionPublishRequest,
    ) -> CommonSchema.NormalResponse:
        return self._post_json(
            SectionApi.publish_section,
            CommonSchema.NormalResponse,
            data,
        )

    def get_section_publish(
        self,
        data: SectionSchema.SectionPublishGetRequest,
    ) -> SectionSchema.SectionPublishGetResponse:
        return self._post_json(
            SectionApi.get_section_publish,
            SectionSchema.SectionPublishGetResponse,
            data,
        )

    def republish_section(
        self,
        data: SectionSchema.SectionRePublishRequest,
    ) -> CommonSchema.NormalResponse:
        return self._post_json(
            SectionApi.republish_section,
            CommonSchema.NormalResponse,
            data,
        )
